==> film_gyaan-1.0.1.tar.gz: lib/src/dx/_endpoints/objects/watch_provider_regions.dart <==
// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class WatchProviderRegions extends Result {
  WatchProviderRegions({
    required this.results,
  });

  factory WatchProviderRegions.fromJson(String str) => WatchProviderRegions.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProviderRegions.fromMap(Map<String, dynamic> json) => WatchProviderRegions(
        results: List<WatchProviderRegionsResult>.from(
          (json['results'] as List<dynamic>).map<dynamic>(
            (dynamic x) => WatchProviderRegionsResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  List<WatchProviderRegionsResult> results;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'results': List<Map<String, dynamic>>.from(
          results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class WatchProviderRegionsResult {
  WatchProviderRegionsResult({
    required this.iso31661,
    required this.englishName,
    required this.nativeName,
  });

  factory WatchProviderRegionsResult.fromJson(String str) =>
      WatchProviderRegionsResult.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProviderRegionsResult.fromMap(Map<String, dynamic> json) =>
      WatchProviderRegionsResult(
        iso31661: json['iso_3166_1'] as String,
        englishName: json['english_name'] as String,
        nativeName: json['native_name'] as String,
      );

  String iso31661;
  String englishName;
  String nativeName;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'iso_3166_1': iso31661,
        'english_name': englishName,
        'native_name': nativeName,
      };
}

==> film_gyaan-1.0.3.tar.gz: lib/src/dx/_endpoints/objects/watch_provider_regions.dart <==
// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

/// @nodoc
class WatchProviderRegions extends Result {
  WatchProviderRegions({
    required this.results,
  });

  factory WatchProviderRegions.fromJson(String str) =>
      WatchProviderRegions.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProviderRegions.fromMap(Map<String, dynamic> json) =>
      WatchProviderRegions(
        results: List<WatchProviderRegionsResult>.from(
          (json['results'] as List<dynamic>).map<dynamic>(
            (dynamic x) => WatchProviderRegionsResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  List<WatchProviderRegionsResult> results;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'results': List<Map<String, dynamic>>.from(
          results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class WatchProviderRegionsResult {
  WatchProviderRegionsResult({
    required this.iso31661,
    required this.englishName,
    required this.nativeName,
  });

  factory WatchProviderRegionsResult.fromJson(String str) =>
      WatchProviderRegionsResult.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProviderRegionsResult.fromMap(Map<String, dynamic> json) =>
      WatchProviderRegionsResult(
        iso31661: json['iso_3166_1'] as String,
        englishName: json['english_name'] as String,
        nativeName: json['native_name'] as String,
      );

  String iso31661;
  String englishName;
  String nativeName;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'iso_3166_1': iso31661,
        'english_name': englishName,
        'native_name': nativeName,
      };
}
